Crate bookshelf

Crate bookshelf 

A library for reading and writing various minecraft files from many different editions and versions of the game.

Modules

bebe
Module for writing and reading Minecraft: Bedrock Edition files
jeje
Module for writing and reading Minecraft: Java Edition files
nbtnbt
Module for serializing and deserializing NBT data

Macros

chunk_id
Gets the entry id in the header tables for the chunk at (x, z).
location_parts
Breaks a location value into it’s offset and size byte
normalize_size
Makes the File a multiple of 4KiB as per specification.
seek_sector
Moves the cursor of the file to a region sector

Structs

BE
Represents big endianness
LE
Represents little endianness

Traits

BinaryFile
Trait for any struct that can converted to and from a binary stream.
Endianness
Trait that allows a struct to be used as an endianness when working with binary
RandomAccess
Trait for structs that interact with random access files such as region files.