A library for reading and writing various minecraft files from many different editions and versions of the game.
Modules
- be
be - Module for writing and reading
Minecraft: Bedrock Editionfiles - je
je - Module for writing and reading
Minecraft: Java Editionfiles - nbt
nbt - Module for serializing and deserializing NBT data
Macros
- chunk_
id - Gets the entry id in the header tables for the chunk at (x, z).
- location_
parts - Breaks a location value into it’s offset and size byte
- normalize_
size - Makes the
Filea multiple of 4KiB as per specification. - seek_
sector - Moves the cursor of the file to a region sector
Structs
Traits
- Binary
File - Trait for any struct that can converted to and from a binary stream.
- Endianness
- Trait that allows a struct to be used as an endianness when working with binary
- Random
Access - Trait for structs that interact with random access files such as region files.